==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/General/fileops/translations/fileops_plugin_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>FileOps</name>
    <message>
        <location filename="../fileops.cpp" line="97"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="98"/>
        <source>Destination directory doesn&apos;t exist</source>
        <translation>Katalog docelowy nie istnieje</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="103"/>
        <source>Copying</source>
        <translation>Kopiowanie</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="104"/>
        <source>Stop</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="134"/>
        <source>Copying file %1/%2</source>
        <translation>Kopiowanie pliku %1/%2</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="176"/>
        <source>Remove files</source>
        <translation>Usuń pliki</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="177"/>
        <source>Are you sure you want to remove %n file(s) from disk?</source>
        <translation>
            <numerusform>Czy jesteś pewien, że chcesz usunąć %n plik(ów) z dysku?</numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>FileOpsFactory</name>
    <message>
        <location filename="../fileopsfactory.cpp" line="30"/>
        <source>File Operations Plugin</source>
        <translation>Wtyczka Operacji na plikach</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="50"/>
        <source>About File Operations Plugin</source>
        <translation>O wtyczce Operacje na plikach</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="51"/>
        <source>Qmmp File Operations Plugin</source>
        <translation>Wtyczka Operacje na plikach dla Qmmp </translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="52"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>Modyfikuj skrót klawiszowy</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>Wciśnij kombinację klawiszy, które chcesz przypisać</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="43"/>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="52"/>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="53"/>
        <location filename="../settingsdialog.cpp" line="133"/>
        <source>Rename</source>
        <translation>Zmień nazwę</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="55"/>
        <location filename="../settingsdialog.cpp" line="135"/>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="138"/>
        <source>New action</source>
        <translation>Nowa akcja</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="192"/>
        <source>Artist</source>
        <translation>Artysta</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="193"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="194"/>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="195"/>
        <source>Tracknumber</source>
        <translation>Numer utworu</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="196"/>
        <source>Genre</source>
        <translation>Gatunek</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="197"/>
        <source>Filename</source>
        <translation>Nazwa pliku</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="198"/>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="199"/>
        <source>Year</source>
        <translation>Rok</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="200"/>
        <source>Comment</source>
        <translation>Komentarz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="216"/>
        <source>Choose a directory</source>
        <translation>Wybierz katalog</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>File Operations Settings</source>
        <translation>Ustawienia wtyczki Operacje na plikach</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Enabled</source>
        <translation>Aktywne</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="53"/>
        <source>Operation</source>
        <translation>Operacja</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>Menu text</source>
        <translation>Tekst w menu</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Shortcut</source>
        <translation>Skróŧ klawiszowy</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>+</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <source>-</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="105"/>
        <location filename="../settingsdialog.ui" line="121"/>
        <location filename="../settingsdialog.ui" line="158"/>
        <location filename="../settingsdialog.ui" line="175"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="148"/>
        <source>Destination:</source>
        <translation>Cel:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="165"/>
        <source>File name pattern:</source>
        <translation></translation>
    </message>
</context>
</TS>

==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/General/fileops/translations/fileops_plugin_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>FileOps</name>
    <message>
        <location filename="../fileops.cpp" line="98"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="99"/>
        <source>Destination directory doesn&apos;t exist</source>
        <translation>Katalog docelowy nie istnieje</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="104"/>
        <source>Copying</source>
        <translation>Kopiowanie</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="105"/>
        <source>Stop</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="146"/>
        <source>Copying file %1/%2</source>
        <translation>Kopiowanie pliku %1/%2</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="189"/>
        <source>Remove files</source>
        <translation>Usuń pliki</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="190"/>
        <source>Are you sure you want to remove %n file(s) from disk?</source>
        <translation>
            <numerusform>Czy napewno chcesz usunąć %n plik(ów) z dysku?</numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>FileOpsFactory</name>
    <message>
        <location filename="../fileopsfactory.cpp" line="30"/>
        <source>File Operations Plugin</source>
        <translation>Wtyczka Operacji na plikach</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="50"/>
        <source>About File Operations Plugin</source>
        <translation>O wtyczce Operacje na plikach</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="51"/>
        <source>Qmmp File Operations Plugin</source>
        <translation>Wtyczka Operacje na plikach dla Qmmp </translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="52"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>Modyfikuj skrót klawiszowy</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>Wciśnij kombinację klawiszy, które chcesz przypisać</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="43"/>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="52"/>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="53"/>
        <location filename="../settingsdialog.cpp" line="133"/>
        <source>Rename</source>
        <translation>Zmień nazwę</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <location filename="../settingsdialog.cpp" line="55"/>
        <location filename="../settingsdialog.cpp" line="135"/>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="138"/>
        <source>New action</source>
        <translation>Nowa akcja</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="192"/>
        <source>Artist</source>
        <translation>Artysta</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="193"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="194"/>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="197"/>
        <source>Genre</source>
        <translation>Gatunek</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="204"/>
        <source>Year</source>
        <translation>Rok</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="198"/>
        <source>Comment</source>
        <translation>Komentarz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="195"/>
        <source>Track number</source>
        <translation>Numer utworu</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="196"/>
        <source>Two-digit track number</source>
        <translation>Dwucyfrowy numer utworu</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="199"/>
        <source>Composer</source>
        <translation>Kompozytor</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="200"/>
        <source>Duration</source>
        <translation>Długość</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="201"/>
        <source>Disc number</source>
        <translation>Numer płyty</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="202"/>
        <source>File name</source>
        <translation>Nazwa pliku</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="203"/>
        <source>File path</source>
        <translation>Ścieżka pliku</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="205"/>
        <source>Condition</source>
        <translation>Warunek</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="221"/>
        <source>Choose a directory</source>
        <translation>Wybierz katalog</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>File Operations Settings</source>
        <translation>Ustawienia wtyczki Operacje na plikach</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Enabled</source>
        <translation>Aktywne</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="53"/>
        <source>Operation</source>
        <translation>Operacja</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>Menu text</source>
        <translation>Tekst w menu</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Shortcut</source>
        <translation>Skróŧ klawiszowy</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="126"/>
        <location filename="../settingsdialog.ui" line="143"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Destination:</source>
        <translation>Cel:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="133"/>
        <source>File name pattern:</source>
        <translation>Wzorzec nazwy pliku:</translation>
    </message>
</context>
</TS>
